==> dokuwiki_0.0.20120125b.orig.tar.gz: dokuwiki-2012-01-25b/inc/lang/id-ni/lang.php <==
<?php
/**
 * idni language file
 *
 * @author Harefa <fidelis@harefa.com>
 * @author Yustinus Waruwu <juswaruwu@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Haogö nga\'örö da\'a';
$lang['btn_source']            = 'Oroma\'ö nga\'örö sindruhu';
$lang['btn_show']              = 'Foroma\'ö nga\'örö';
$lang['btn_create']            = 'Fazökhi nga\'öro';
$lang['btn_search']            = 'Alui';
$lang['btn_save']              = 'Irö\'ö';
$lang['btn_preview']           = 'Foroma\'ö zikhala';
$lang['btn_top']               = 'Angawuli ba mböröta';
$lang['btn_newer']             = '<< sibohou';
$lang['btn_older']             = 'si no ara >>';
$lang['btn_revs']              = 'nifawu\'a si\'oföna';
$lang['btn_recent']            = 'Lahe nibohouni';
$lang['btn_upload']            = 'Fa\'oeh\'ö';
$lang['btn_cancel']            = 'Lö alua';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Ehaogö';
$lang['btn_login']             = 'Felalö bakha';
$lang['btn_logout']            = 'Möi baero';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Bohouni';
$lang['btn_delete']            = 'Heta';
$lang['btn_back']              = 'Fulifuri';
$lang['btn_backlink']          = 'Link fangawuli';
$lang['btn_backtomedia']       = 'Angawuli ba filianö Mediafile';
$lang['btn_profile']           = 'Famohouni pörofile';
$lang['btn_reset']             = 'Fawu\'a';
$lang['btn_resendpwd']         = 'Fa\'ohe\'ö kode sibohou';
$lang['btn_draft']             = 'Fawu\'a wanura';
$lang['btn_draftdel']          = 'Heta zura';
$lang['btn_register']          = 'Fasura\'ö';
$lang['loggedinas']            = 'Möi bakha zotöi';
$lang['user']                  = 'Töi';
$lang['pass']                  = 'Kode';
$lang['newpass']               = 'Kode sibohou';
$lang['oldpass']               = 'Faduhu\'ö kode';
$lang['passchk']               = 'Sura sakalitö';
$lang['remember']              = 'Töngöni ndra\'o';
$lang['fullname']              = 'Töi safönu';
$lang['email']                 = 'Imele';
$lang['profile']               = 'Töi pörofile';
$lang['badlogin']              = 'Bologö dödöu, fasala döi faoma kode.';
$lang['minoredit']             = 'Famawu\'a ma\'ifu';
$lang['regmissing']            = 'Bologö dödöu, si lö tola lö\'ö öfo\'ösi fefu nahia si tohöna.';
$lang['reguexists']            = 'Bologö dödöu, no so zangoguna\'ö töi da\'a.';
$lang['regsuccess']            = 'No tefazökhi akunö ba tefa\'ohe\'ö kode ba imele.';
$lang['regsuccess2']           = 'No tefazökhi akunö';
$lang['regmailfail']           = 'Oroma wa so ma\'ifu zifawuka ba wama\'ohe\'ö imele kode. Fuli sofu khö admin!';
$lang['regbadmail']            = 'Imele nibe\'emö lö atulö - na ö\'ila wa fasala da\'a, sofu khö admin';
$lang['regbadpass']            = 'Dombuadombua kode nibe\'emö lö fagölö, fuli sura.';
$lang['regpwmail']             = 'Kode DokuWiki';
$lang['reghere']               = 'Hadia no so akunömö? Na lö\'ö, fazökhi sambua.';
$lang['profna']                = 'Lö tetehegö ba wiki da\'a ba wamawu\'a pörofile';
$lang['profnochange']          = 'Lö hadöi nifawu\'ö, lö hadöi ni\'ohalöwögöi';
$lang['profnoempty']           = 'Lö tetehegö na lö hadöi töi ma imele.';
$lang['profchanged']           = 'Pörofile zangoguna\'ö no tebohouni.';
$lang['pwdforget']             = 'Hadia olifu\'ö kode? Fuli halö kode';
$lang['resendna']              = 'Lö tetehegi ba wiki da\'a wama\'ohe\'ö kode dua kali.';
$lang['resendpwd']             = 'Tefa\'ohe\'ö kode sibahou khö';
$lang['resendpwdmissing']      = 'Bologö dödöu, si lö tola lö\'ö öfo\'ösi fefu nahia si tohöna.';
$lang['resendpwdnouser']       = 'Bologö dödöu, lö masöndra zangoguna da\'a ba database.';
$lang['resendpwdconfirm']      = 'No tefaohe\'ö link famaduhu\'ö ba imele.';
$lang['resendpwdsuccess']      = 'No tefa\'ohe\'ö kode sibohou ba imele.';
$lang['txt_upload']            = 'Fili file ni fa\'ohe\'ö';
$lang['js']['notsavedyet']     = "Famawu\'a si lö mu\'irö\'ö taya. \nSinduhu ötohugö?";
$lang['mediaselect']           = 'Media file';

==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/inc/lang/id-ni/lang.php <==
<?php
/**
 * idni language file
 *
 * @author Harefa <fidelis@harefa.com>
 * @author Yustinus Waruwu <juswaruwu@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Haogö nga\'örö da\'a';
$lang['btn_source']            = 'Oroma\'ö nga\'örö sindruhu';
$lang['btn_show']              = 'Foroma\'ö nga\'örö';
$lang['btn_create']            = 'Fazökhi nga\'öro';
$lang['btn_search']            = 'Alui';
$lang['btn_save']              = 'Irö\'ö';
$lang['btn_preview']           = 'Foroma\'ö zikhala';
$lang['btn_top']               = 'Angawuli ba mböröta';
$lang['btn_newer']             = '<< sibohou';
$lang['btn_older']             = 'si no ara >>';
$lang['btn_revs']              = 'nifawu\'a si\'oföna';
$lang['btn_recent']            = 'Lahe nibohouni';
$lang['btn_upload']            = 'Fa\'oeh\'ö';
$lang['btn_cancel']            = 'Lö alua';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Ehaogö';
$lang['btn_login']             = 'Felalö bakha';
$lang['btn_logout']            = 'Möi baero';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Bohouni';
$lang['btn_delete']            = 'Heta';
$lang['btn_back']              = 'Fulifuri';
$lang['btn_backlink']          = 'Link fangawuli';
$lang['btn_backtomedia']       = 'Angawuli ba filianö Mediafile';
$lang['btn_profile']           = 'Famohouni pörofile';
$lang['btn_reset']             = 'Fawu\'a';
$lang['btn_draft']             = 'Fawu\'a wanura';
$lang['btn_draftdel']          = 'Heta zura';
$lang['btn_register']          = 'Fasura\'ö';
$lang['loggedinas']            = 'Möi bakha zotöi';
$lang['user']                  = 'Töi';
$lang['pass']                  = 'Kode';
$lang['newpass']               = 'Kode sibohou';
$lang['oldpass']               = 'Faduhu\'ö kode';
$lang['passchk']               = 'Sura sakalitö';
$lang['remember']              = 'Töngöni ndra\'o';
$lang['fullname']              = 'Töi safönu';
$lang['email']                 = 'Imele';
$lang['profile']               = 'Töi pörofile';
$lang['badlogin']              = 'Bologö dödöu, fasala döi faoma kode.';
$lang['minoredit']             = 'Famawu\'a ma\'ifu';
$lang['regmissing']            = 'Bologö dödöu, si lö tola lö\'ö öfo\'ösi fefu nahia si tohöna.';
$lang['reguexists']            = 'Bologö dödöu, no so zangoguna\'ö töi da\'a.';
$lang['regsuccess']            = 'No tefazökhi akunö ba tefa\'ohe\'ö kode ba imele.';
$lang['regsuccess2']           = 'No tefazökhi akunö';
$lang['regmailfail']           = 'Oroma wa so ma\'ifu zifawuka ba wama\'ohe\'ö imele kode. Fuli sofu khö admin!';
$lang['regbadmail']            = 'Imele nibe\'emö lö atulö - na ö\'ila wa fasala da\'a, sofu khö admin';
$lang['regbadpass']            = 'Dombuadombua kode nibe\'emö lö fagölö, fuli sura.';
$lang['regpwmail']             = 'Kode DokuWiki';
$lang['reghere']               = 'Hadia no so akunömö? Na lö\'ö, fazökhi sambua.';
$lang['profna']                = 'Lö tetehegö ba wiki da\'a ba wamawu\'a pörofile';
$lang['profnochange']          = 'Lö hadöi nifawu\'ö, lö hadöi ni\'ohalöwögöi';
$lang['profnoempty']           = 'Lö tetehegö na lö hadöi töi ma imele.';
$lang['profchanged']           = 'Pörofile zangoguna\'ö no tebohouni.';
$lang['pwdforget']             = 'Hadia olifu\'ö kode? Fuli halö kode';
$lang['resendna']              = 'Lö tetehegi ba wiki da\'a wama\'ohe\'ö kode dua kali.';
$lang['resendpwdmissing']      = 'Bologö dödöu, si lö tola lö\'ö öfo\'ösi fefu nahia si tohöna.';
$lang['resendpwdnouser']       = 'Bologö dödöu, lö masöndra zangoguna da\'a ba database.';
$lang['resendpwdconfirm']      = 'No tefaohe\'ö link famaduhu\'ö ba imele.';
$lang['resendpwdsuccess']      = 'No tefa\'ohe\'ö kode sibohou ba imele.';
$lang['txt_upload']            = 'Fili file ni fa\'ohe\'ö';
$lang['js']['notsavedyet']     = 'Famawu\'a si lö mu\'irö\'ö taya. \nSinduhu ötohugö?';
$lang['mediaselect']           = 'Media file';
